@@ -170,7 +170,7 @@
 #define HAVE_DECL_MADVISE 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
 #define HAVE_MALLINFO 1
-/* #undef HAVE_MALLINFO2 */
+#define HAVE_MALLINFO2 1
 /* #undef HAVE_MALLOC_ZONE */
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -529,16 +529,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 4
+#define MYSQL_VERSION_PATCH 7
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.4"
+#define PACKAGE_STRING "MySQL Server 10.6.7"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.4"
-#define VERSION "10.6.4"
+#define PACKAGE_VERSION "10.6.7"
+#define VERSION "10.6.7"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
